spike.Display package — spike 0.99.23 documentation

# spike.Display package

## Submodules

## spike.Display.fakeplot module

fakeplot.py

This library allows to fake the matplotlib.plot module where it has not been installed.

Created by Marc-André on 2010-03-22. Copyright (c) 2010 IGBMC. All rights reserved.

`spike.Display.fakeplot.` `contour`(*args, **key)

`spike.Display.fakeplot.` `contourf`(*args, **key)

`spike.Display.fakeplot.` `errorbar`(*args, **key)

class `spike.Display.fakeplot.` `fake`(*args, **key)

  Bases: `object`

  fake figure object

  `add_subplot`(*args, **key)
  `contour`(*args, **key)
  `contourf`(*args, **key)
  `errorbar`(*args, **key)
  `figure`(*args, **key)
  `grid`(*args, **key)
  `hist`(*args, **key)
  `legend`(*args, **key)
  `loglog`(*args, **key)
  `plot`(*args, **key)
  `semilogx`(*args, **key)
  `semilogy`(*args, **key)
  `set_title`(*args, **key)
  `set_xlabel`(*args, **key)
  `set_xscale`(*args, **key)
  `set_xticklabels`(*args, **key)
  `set_ylabel`(*args, **key)
  `set_yscale`(*args, **key)
  `set_yticklabels`(*args, **key)
  `show`(*args, **key)
  `suptitle`(*args, **key)
  `text`(*args, **key)
  `title`(*args, **key)
  `xlabel`(*args, **key)
  `xlim`(*args, **key)
  `xscale`(*args, **key)
  `ylabel`(*args, **key)
  `ylim`(*args, **key)
  `yscale`(*args, **key)

`spike.Display.fakeplot.` `figure`(*args, **key)

`spike.Display.fakeplot.` `gca`()

`spike.Display.fakeplot.` `grid`(*args, **key)

`spike.Display.fakeplot.` `hist`(*args, **key)

`spike.Display.fakeplot.` `legend`(*args, **key)

`spike.Display.fakeplot.` `loglog`(*args, **key)

`spike.Display.fakeplot.` `plot`(*args, **key)

`spike.Display.fakeplot.` `semilogx`(*args, **key)

`spike.Display.fakeplot.` `semilogy`(*args, **key)

`spike.Display.fakeplot.` `show`(*args, **key)

`spike.Display.fakeplot.` `subplot`(*args, **key)

`spike.Display.fakeplot.` `suptitle`(*args, **key)

`spike.Display.fakeplot.` `text`(*args, **key)

`spike.Display.fakeplot.` `title`(*args, **key)

`spike.Display.fakeplot.` `xlabel`(*args, **key)

`spike.Display.fakeplot.` `xlim`(*args, **key)

`spike.Display.fakeplot.` `xscale`(*args, **key)

`spike.Display.fakeplot.` `ylabel`(*args, **key)

`spike.Display.fakeplot.` `ylim`(*args, **key)

`spike.Display.fakeplot.` `yscale`(*args, **key)

## spike.Display.testplot module

testplot

allow to import either matplotlib.pyplor or fakeplot depending on the PLOT flag

usage:

import Display.testplot as testplot testplot.PLOT = False # eventually plt = testplot.plot()

Created by Marc-André on 2012-10-03. Copyright (c) 2012 IGBMC. All rights reserved.

`spike.Display.testplot.` `plot`()

  import the current plotpackage usage:

  import spike.Display.testplot as testplot plt = testplot.plot()

  then use plt as matplotlib

`spike.Display.testplot.` `plotname`()

  returns current plot package name

## Module contents

Small Utilities

The real display engine is in NPKData display()

Created by Marc-André on 2011-03-20. Copyright (c) 2011 IGBMC. All rights reserved.

`spike.Display.` `main`()